@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008 gocept gmbh & co. kg
 # See also LICENSE.txt
-# $Id: db.py 6599 2008-09-12 11:31:37Z mac $
+# $Id: db.py 6787 2008-10-13 12:13:19Z sweh $
 
 import gocept.country.interfaces
 import pycountry
@@ -25,7 +25,7 @@ class Data(object):
     def __eq__(self, other):
         if not other:
             return False
-        if not isinstance(other, self.__class__):
+        if other.__class__ != self.__class__:
             return False
         return self.token == other.token
 
